pub struct TableViewComponentBase<'a, T, F>{
pub config: Config,
/* private fields */
}Fields
config: ConfigImplementations
Sourceimpl<T, F> TableViewComponentBase<'_, T, F>where
T: StructTable + DeserializeOwned + ResourceKey,
for<'a> &'a T: StructTable,
F: Default + Display,
impl<T, F> TableViewComponentBase<'_, T, F>where
T: StructTable + DeserializeOwned + ResourceKey,
for<'a> &'a T: StructTable,
F: Default + Display,
pub fn new() -> Self
pub fn set_config(&mut self, config: Config) -> Result<(), TuiError>
pub fn get_config(&self) -> &Config
pub fn get_command_tx(&self) -> Option<&UnboundedSender<Action>>
pub fn get_output_config(&mut self) -> &mut ViewConfig
pub fn set_command_tx( &mut self, tx: UnboundedSender<Action>, ) -> Result<(), TuiError>
pub fn set_loading(&mut self, loading: bool)
pub fn app_tick(&mut self) -> Result<(), TuiError>
pub fn render_tick(&mut self) -> Result<(), TuiError>
pub fn cursor_first(&mut self) -> Result<(), TuiError>
pub fn cursor_last(&mut self) -> Result<(), TuiError>
pub fn cursor_down(&mut self) -> Result<(), TuiError>
pub fn cursor_up(&mut self) -> Result<(), TuiError>
pub fn cursor_page_down(&mut self) -> Result<(), TuiError>
pub fn cursor_page_up(&mut self) -> Result<(), TuiError>
pub fn cursor_left(&mut self) -> Result<(), TuiError>
pub fn cursor_right(&mut self) -> Result<(), TuiError>
pub fn key_tab(&mut self) -> Result<(), TuiError>
pub fn set_describe_content(&mut self) -> Result<(), TuiError>
pub fn handle_key_events( &mut self, key: KeyEvent, ) -> Result<Option<Action>, TuiError>
pub fn set_data(&mut self, data: Vec<Value>) -> Result<(), TuiError>
Sourcepub fn sync_table_data(&mut self) -> Result<(), TuiError>
pub fn sync_table_data(&mut self) -> Result<(), TuiError>
Synchronize table data from internal vector of typed entries
Sourcepub fn update_row_data(&mut self, data: Value) -> Result<(), TuiError>
pub fn update_row_data(&mut self, data: Value) -> Result<(), TuiError>
Update single record with the new data
pub fn get_filters(&self) -> &F
pub fn set_filters(&mut self, filters: F)
pub fn draw( &mut self, f: &mut Frame<'_>, area: Rect, title: &str, ) -> Result<(), TuiError>
pub fn render_table(&mut self, f: &mut Frame<'_>, area: Rect) -> Result<()>
pub fn render_scrollbar(&mut self, f: &mut Frame<'_>, area: Rect) -> Result<()>
pub fn render_content<S: AsRef<str>>( &mut self, title: S, frame: &mut Frame<'_>, area: Rect, ) -> Result<(), TuiError>
pub fn get_selected(&self) -> Option<&T>
Sourcepub fn get_item_row_by_res_id_mut(
&mut self,
search_id: &String,
) -> Option<&mut T>
pub fn get_item_row_by_res_id_mut( &mut self, search_id: &String, ) -> Option<&mut T>
Get mutable reference to the row with the typed data matching resource id
Sourcepub fn delete_item_row_by_res_id_mut(
&mut self,
search_id: &String,
) -> Result<Option<usize>>
pub fn delete_item_row_by_res_id_mut( &mut self, search_id: &String, ) -> Result<Option<usize>>
delete the row with the typed data matching resource id
pub fn get_selected_raw(&self) -> Option<&Value>
pub fn get_selected_resource_id(&self) -> Result<Option<String>, TuiError>
pub fn describe_selected_entry(&self) -> Result<(), TuiError>
Sourcepub fn append_new_row(&mut self, data: Value) -> Result<(), TuiError>
pub fn append_new_row(&mut self, data: Value) -> Result<(), TuiError>
append new row.